@@ -2,11 +2,12 @@
 Utilities for determining application-specific dirs. See <https://github.com/platformdirs/platformdirs> for details and
 usage.
 """
-import importlib
+from __future__ import annotations
+
 import os
 import sys
 from pathlib import Path
-from typing import TYPE_CHECKING, Optional, Type, Union
+from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
     from typing_extensions import Literal  # pragma: no cover
@@ -15,17 +16,23 @@ from .api import PlatformDirsABC
 from .version import __version__, __version_info__
 
 
-def _set_platform_dir_class() -> Type[PlatformDirsABC]:
-    if os.getenv("ANDROID_DATA") == "/data" and os.getenv("ANDROID_ROOT") == "/system":
-        module, name = "platformdirs.android", "Android"
-    elif sys.platform == "win32":
-        module, name = "platformdirs.windows", "Windows"
+def _set_platform_dir_class() -> type[PlatformDirsABC]:
+    if sys.platform == "win32":
+        from platformdirs.windows import Windows as Result
     elif sys.platform == "darwin":
-        module, name = "platformdirs.macos", "MacOS"
+        from platformdirs.macos import MacOS as Result
     else:
-        module, name = "platformdirs.unix", "Unix"
-    result: Type[PlatformDirsABC] = getattr(importlib.import_module(module), name)
-    return result
+        from platformdirs.unix import Unix as Result
+
+    if os.getenv("ANDROID_DATA") == "/data" and os.getenv("ANDROID_ROOT") == "/system":
+        from platformdirs.android import _android_folder
+
+        if _android_folder() is not None:
+            from platformdirs.android import Android
+
+            return Android  # return to avoid redefinition of result
+
+    return Result
 
 
 PlatformDirs = _set_platform_dir_class()  #: Currently active platform
@@ -33,9 +40,9 @@ AppDirs = PlatformDirs  #: Backwards compatibility with appdirs
 
 
 def user_data_dir(
-    appname: Optional[str] = None,
-    appauthor: Union[str, None, "Literal[False]"] = None,
-    version: Optional[str] = None,
+    appname: str | None = None,
+    appauthor: str | None | Literal[False] = None,
+    version: str | None = None,
     roaming: bool = False,
 ) -> str:
     """
@@ -49,9 +56,9 @@ def user_data_dir(
 
 
 def site_data_dir(
-    appname: Optional[str] = None,
-    appauthor: Union[str, None, "Literal[False]"] = None,
-    version: Optional[str] = None,
+    appname: str | None = None,
+    appauthor: str | None | Literal[False] = None,
+    version: str | None = None,
     multipath: bool = False,
 ) -> str:
     """
@@ -65,9 +72,9 @@ def site_data_dir(
 
 
 def user_config_dir(
-    appname: Optional[str] = None,
-    appauthor: Union[str, None, "Literal[False]"] = None,
-    version: Optional[str] = None,
+    appname: str | None = None,
+    appauthor: str | None | Literal[False] = None,
+    version: str | None = None,
     roaming: bool = False,
 ) -> str:
     """
@@ -81,9 +88,9 @@ def user_config_dir(
 
 
 def site_config_dir(
-    appname: Optional[str] = None,
-    appauthor: Union[str, None, "Literal[False]"] = None,
-    version: Optional[str] = None,
+    appname: str | None = None,
+    appauthor: str | None | Literal[False] = None,
+    version: str | None = None,
     multipath: bool = False,
 ) -> str:
     """
@@ -97,9 +104,9 @@ def site_config_dir(
 
 
 def user_cache_dir(
-    appname: Optional[str] = None,
-    appauthor: Union[str, None, "Literal[False]"] = None,
-    version: Optional[str] = None,
+    appname: str | None = None,
+    appauthor: str | None | Literal[False] = None,
+    version: str | None = None,
     opinion: bool = True,
 ) -> str:
     """
@@ -113,9 +120,9 @@ def user_cache_dir(
 
 
 def user_state_dir(
-    appname: Optional[str] = None,
-    appauthor: Union[str, None, "Literal[False]"] = None,
-    version: Optional[str] = None,
+    appname: str | None = None,
+    appauthor: str | None | Literal[False] = None,
+    version: str | None = None,
     roaming: bool = False,
 ) -> str:
     """
@@ -129,9 +136,9 @@ def user_state_dir(
 
 
 def user_log_dir(
-    appname: Optional[str] = None,
-    appauthor: Union[str, None, "Literal[False]"] = None,
-    version: Optional[str] = None,
+    appname: str | None = None,
+    appauthor: str | None | Literal[False] = None,
+    version: str | None = None,
     opinion: bool = True,
 ) -> str:
     """
@@ -152,9 +159,9 @@ def user_documents_dir() -> str:
 
 
 def user_runtime_dir(
-    appname: Optional[str] = None,
-    appauthor: Union[str, None, "Literal[False]"] = None,
-    version: Optional[str] = None,
+    appname: str | None = None,
+    appauthor: str | None | Literal[False] = None,
+    version: str | None = None,
     opinion: bool = True,
 ) -> str:
     """
@@ -168,9 +175,9 @@ def user_runtime_dir(
 
 
 def user_data_path(
-    appname: Optional[str] = None,
-    appauthor: Union[str, None, "Literal[False]"] = None,
-    version: Optional[str] = None,
+    appname: str | None = None,
+    appauthor: str | None | Literal[False] = None,
+    version: str | None = None,
     roaming: bool = False,
 ) -> Path:
     """
@@ -184,9 +191,9 @@ def user_data_path(
 
 
 def site_data_path(
-    appname: Optional[str] = None,
-    appauthor: Union[str, None, "Literal[False]"] = None,
-    version: Optional[str] = None,
+    appname: str | None = None,
+    appauthor: str | None | Literal[False] = None,
+    version: str | None = None,
     multipath: bool = False,
 ) -> Path:
     """
@@ -200,9 +207,9 @@ def site_data_path(
 
 
 def user_config_path(
-    appname: Optional[str] = None,
-    appauthor: Union[str, None, "Literal[False]"] = None,
-    version: Optional[str] = None,
+    appname: str | None = None,
+    appauthor: str | None | Literal[False] = None,
+    version: str | None = None,
     roaming: bool = False,
 ) -> Path:
     """
@@ -216,9 +223,9 @@ def user_config_path(
 
 
 def site_config_path(
-    appname: Optional[str] = None,
-    appauthor: Union[str, None, "Literal[False]"] = None,
-    version: Optional[str] = None,
+    appname: str | None = None,
+    appauthor: str | None | Literal[False] = None,
+    version: str | None = None,
     multipath: bool = False,
 ) -> Path:
     """
@@ -232,9 +239,9 @@ def site_config_path(
 
 
 def user_cache_path(
-    appname: Optional[str] = None,
-    appauthor: Union[str, None, "Literal[False]"] = None,
-    version: Optional[str] = None,
+    appname: str | None = None,
+    appauthor: str | None | Literal[False] = None,
+    version: str | None = None,
     opinion: bool = True,
 ) -> Path:
     """
@@ -248,9 +255,9 @@ def user_cache_path(
 
 
 def user_state_path(
-    appname: Optional[str] = None,
-    appauthor: Union[str, None, "Literal[False]"] = None,
-    version: Optional[str] = None,
+    appname: str | None = None,
+    appauthor: str | None | Literal[False] = None,
+    version: str | None = None,
     roaming: bool = False,
 ) -> Path:
     """
@@ -264,9 +271,9 @@ def user_state_path(
 
 
 def user_log_path(
-    appname: Optional[str] = None,
-    appauthor: Union[str, None, "Literal[False]"] = None,
-    version: Optional[str] = None,
+    appname: str | None = None,
+    appauthor: str | None | Literal[False] = None,
+    version: str | None = None,
     opinion: bool = True,
 ) -> Path:
     """
@@ -287,9 +294,9 @@ def user_documents_path() -> Path:
 
 
 def user_runtime_path(
-    appname: Optional[str] = None,
-    appauthor: Union[str, None, "Literal[False]"] = None,
-    version: Optional[str] = None,
+    appname: str | None = None,
+    appauthor: str | None | Literal[False] = None,
+    version: str | None = None,
     opinion: bool = True,
 ) -> Path:
     """
