@@ -1,12 +1,13 @@
+from __future__ import annotations
+
 import sys
 from subprocess import check_output
-from typing import Tuple
 
 from platformdirs import __version__
 from platformdirs.__main__ import PROPS
 
 
-def test_props_same_as_test(props: Tuple[str, ...]) -> None:
+def test_props_same_as_test(props: tuple[str, ...]) -> None:
     assert PROPS == props
 
 
